@@ -197,7 +197,7 @@ class IndoNLGTokenizer(PreTrainedTokenizer):
                 decoder_input_batch = self(decoder_inputs, return_attention_mask=False)
                 
                 if type(decoder_inputs) == str:
-                    decoder_input_batch['input_ids'] = [lang_id, self.bos_token_id] + decoder_input_batch['input_ids'] + [self.eos_token_id]
+                    decoder_input_batch['input_ids'] = [decoder_lang_id, self.bos_token_id] + decoder_input_batch['input_ids'] + [self.eos_token_id]
                 else:
                     decoder_input_batch['input_ids'] = list(map(lambda input_ids: [lang_id, self.bos_token_id] + input_ids + [self.eos_token_id], decoder_input_batch['input_ids']))
                 # Padding
